
Executive
=========


.. automodule:: opendssdirect.Executive
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Executive.Command

    Get i‐th command (with i as a string)

.. function:: opendssdirect.Executive.CommandHelp

    Get help string for i‐th command (with i as a string)

.. function:: opendssdirect.Executive.NumCommands

    Number of DSS Executive Commands

.. function:: opendssdirect.Executive.NumOptions

    Number of DSS Executive Options

.. function:: opendssdirect.Executive.Option

    Get i‐th option (with i as a string)

.. function:: opendssdirect.Executive.OptionHelp

    Get help string for i‐th option (with i as a string)

.. function:: opendssdirect.Executive.OptionValue

    Get present value of i‐th option (with i as a string)

